@@ -30,6 +30,8 @@ class Message:
         self.mentions: Tuple[str] = ()
         self.system_message: Optional[str] = None
         self.bot: 'BaseBot' = bot
+        self.reward: Optional[str] = None
+        self.msg_id: Optional[str] = None
 
         self._parse()
 
@@ -51,6 +53,10 @@ class Message:
         if self.tags is not None and 'system-msg' in self.tags.all_tags:
             self.system_message = self.tags.all_tags['system-msg'].replace(r'\s', ' ')
 
+        self.msg_id = (self.tags.all_tags.get('msg-id')
+                       if self.tags is not None
+                       else None)
+
     def _parse_user_part(self) -> bool:
         m = RE_USER_PART.search(self.raw_msg)
         if m:
@@ -97,6 +103,11 @@ class Message:
             self.tags = Tags(m['tags'])
             self.mentions = get_message_mentions(self)
 
+            # checking if its a channel point redemption
+            self.reward = self.tags.all_tags.get('msg-id')
+            if self.reward is not None:
+                self.type = MessageType.CHANNEL_POINTS_REDEMPTION
+
         return bool(m)
 
     def _parse_usernotice(self) -> bool:
@@ -199,6 +210,9 @@ class Message:
         elif self.type is MessageType.USER_PART:
             return f'{self.author} left {self.channel_name}'
 
+        elif self.type is MessageType.CHANNEL_POINTS_REDEMPTION:
+            return f'{self.author} redeemws reward {self.reward} in #{self.channel_name}'
+
         return self.raw_msg
 
     def __len__(self):
